==> modlogan_0.7.12.orig.tar.gz: modlogan-0.7.12.orig/src/datatypes/webhist/datatype.h <==
/*
** Modular Logfile Analyzer
** Copyright 2000 Jan Kneschke <jan@kneschke.de>
**
** Homepage: http://www.kneschke.de/projekte/modlogan
**

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version, and provided that the above
    copyright and permission notice is included with all distributed
    copies of this or derived software.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA

**
** $Id: datatype.h,v 1.5 2001/10/06 16:32:17 ostborn Exp $
*/

#ifndef _M_DATA_WEBHIST_H_
#define _M_DATA_WEBHIST_H_

#include <zlib.h>
#include <libxml/tree.h>

#include "mdatatypes.h"
#include "mstate.h"

int	mdata_WebHist_to_xml(gzFile *fd, mdata *data);
int     mdata_WebHist_from_xml(mstate_stack *m, int tagtype, mdata *data, int type, const xmlChar *value, const xmlChar **attrs);

mdata  *mdata_WebHist_create(const char *str, 
	unsigned int hits, unsigned int files,
	unsigned int pages, unsigned int visits,
	unsigned int hosts, unsigned int year,
	unsigned int month, unsigned int week,
	unsigned int days_passed, double xfersize );
	
mdata  *mdata_WebHist_create_by_state(mstate *state);

int     mdata_WebHist_free(mdata *data);
mdata  *mdata_WebHist_copy(mdata *src);
int     mdata_WebHist_append(mdata *dst, mdata *src);

#endif

==> modlogan_0.8.7.orig.tar.gz: modlogan-0.8.7/src/datatypes/webhist/datatype.h <==
/*
** Modular Logfile Analyzer
** Copyright 2000 Jan Kneschke <jan@kneschke.de>
**
** Homepage: http://www.modlogan.org
**

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version, and provided that the above
    copyright and permission notice is included with all distributed
    copies of this or derived software.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA

**
** $Id: datatype.h,v 1.10 2003/01/06 11:08:20 ostborn Exp $
*/

#ifndef _M_DATA_WEBHIST_H_
#define _M_DATA_WEBHIST_H_

#include "mdatatypes.h"
#include "mstate.h"

int	mdata_WebHist_to_xml(gzFile *fd, mdata *data);
int     mdata_WebHist_from_xml(void *user_data, int tagtype, const xmlChar *value, const xmlChar **attrs);

mdata  *mdata_WebHist_create(const char *str,
	unsigned int hits, unsigned int files,
	unsigned int pages, unsigned int visits,
	unsigned int hosts, unsigned int year,
	unsigned int month, unsigned int week,
	unsigned int days_passed, double xfersize );

mdata  *mdata_WebHist_create_by_state(mstate *state);

mdata  *mdata_WebHist_init();
int     mdata_WebHist_free(mdata *data);
mdata  *mdata_WebHist_copy(mdata *src);
int     mdata_WebHist_append(mdata *dst, mdata *src);

#endif
